@@ -1,4 +1,6 @@
 """Indexing related helper methods."""
+import warnings
+
 from ._grouper import group_by_nothing, solar_offset
 from ._index import (
     all_datasets,
@@ -14,7 +16,6 @@ from ._index import (
     month_range,
     ordered_dss,
     parse_doc_stream,
-    patch_urls,
     product_from_yaml,
     season_range,
     time_range,
@@ -22,6 +23,8 @@ from ._index import (
 from ._utm import mk_utm_gs, utm_region_code, utm_tile_dss, utm_zone_to_epsg
 from ._uuid import odc_uuid
 
+warnings.warn("odc.index is being removed", FutureWarning)
+
 __all__ = (
     "from_yaml_doc_stream",
     "from_metadata_stream",
@@ -39,7 +42,6 @@ __all__ = (
     "chopped_dss",
     "all_datasets",
     "product_from_yaml",
-    "patch_urls",
     "odc_uuid",
     "utm_region_code",
     "utm_zone_to_epsg",
