@@ -7,7 +7,8 @@ Utilities for translating STAC Items to EO3 Datasets.
 import datetime
 import uuid
 from collections import namedtuple
-from functools import singledispatch
+from copy import copy
+from functools import partial, singledispatch
 from typing import (
     Any,
     Dict,
@@ -38,14 +39,15 @@ from pystac.extensions.projection import ProjectionExtension
 from pystac.extensions.raster import RasterExtension
 from toolz import dicttoolz
 
-from odc.index import odc_uuid
-
 T = TypeVar("T")
 BandMetadata = namedtuple("BandMetadata", ["data_type", "nodata", "unit"])
 ConversionConfig = Dict[str, Any]
 
 EPSG4326 = CRS("EPSG:4326")
 
+# uuid.uuid5(uuid.NAMESPACE_URL, "https://stacspec.org")
+UUID_NAMESPACE_STAC = uuid.UUID("55d26088-a6d0-5c77-bf9a-3a7f3c6a6dab")
+
 # Mapping between EO3 field names and STAC properties object field names
 # EO3 metadata was defined before STAC 1.0, so we used some extensions
 # that are now part of the standard instead
@@ -264,6 +266,8 @@ def compute_eo3_grids(
     """
     # pylint: disable=too-many-locals
 
+    assert len(assets) > 0
+
     def gbox_name(geobox: GeoBox) -> str:
         gsd = geobox_gsd(geobox)
         return f"g{gsd:g}"
@@ -491,19 +495,31 @@ def infer_dc_product_from_item(
 
     collection_id = _collection_id(item)
 
-    _cfg = cfg.get("*", {})
+    _cfg = copy(cfg.get("*", {}))
     _cfg.update(cfg.get(collection_id, {}))
 
     quiet = _cfg.get("warnings", "all") == "ignore"
     band_cfg = _cfg.get("assets", {})
+    ignore_proj = _cfg.get("ignore_proj", False)
 
-    def _keep(kv):
+    def _keep(kv, check_proj):
         name, asset = kv
         if name in band_cfg:
             return True
-        return is_raster_data(asset, check_proj=True)
+        return is_raster_data(asset, check_proj=check_proj)
 
-    data_bands: Dict[str, pystac.asset.Asset] = dicttoolz.itemfilter(_keep, item.assets)
+    has_proj = False if ignore_proj else has_proj_ext(item)
+    data_bands: Dict[str, pystac.asset.Asset] = dicttoolz.itemfilter(
+        partial(_keep, check_proj=has_proj), item.assets
+    )
+    if len(data_bands) == 0 and has_proj is True:
+        # Proj is enabled but no Asset has all the proj data
+        has_proj = False
+        data_bands = dicttoolz.itemfilter(partial(_keep, check_proj=False), item.assets)
+        _cfg.update(ignore_proj=True)
+
+    if len(data_bands) == 0:
+        raise ValueError("Unable to find any bands")
 
     aliases = alias_map_from_eo(item, quiet=quiet)
     aliases.update(_cfg.get("aliases", {}))
@@ -523,7 +539,7 @@ def infer_dc_product_from_item(
     # We assume that grouping of data bands into grids is consistent across
     # entire collection, so we compute it once and keep it on a product object
     # at least for now.
-    if has_proj_ext(item):
+    if has_proj:
         _, band2grid = compute_eo3_grids(data_bands)
     else:
         band2grid = _band2grid_from_gsd(data_bands)
@@ -548,11 +564,23 @@ def _compute_uuid(
     except ValueError:
         pass
 
-    # 2. .id, .collection_id, [extras]
-    _extras = (
-        {} if extras is None else {key: item.properties.get(key, "") for key in extras}
-    )
-    return odc_uuid(_collection_id(item), "stac", [], stac_id=item.id, **_extras)
+    # 2. .collection_id, .id, [extras]
+    #
+    # Deterministic UUID is using uuid5 on a string constructed from Item properties like so
+    #
+    #  <collection_id>\n
+    #  <item_id>\n
+    #  extras[i]=item.properties[extras[i]]\n
+    #
+    #  At a minimum it's just 2 lines collection_id and item.id If extra keys are requested, these
+    #  are sorted first and then appended one per line in `{key}={value}` format where value is
+    #  looked up from item properties, if key is missing then {value} is set to empty string.
+    hash_srcs = [_collection_id(item), item.id]
+    if extras is not None:
+        tags = [f"{k}={str(item.properties.get(k, ''))}" for k in sorted(extras)]
+        hash_srcs.extend(tags)
+    hash_text = "\n".join(hash_srcs) + "\n"  # < ensure last line ends on \n
+    return uuid.uuid5(UUID_NAMESPACE_STAC, hash_text)
 
 
 def item_to_ds(item: pystac.item.Item, product: DatasetType) -> Dataset:
@@ -564,8 +592,9 @@ def item_to_ds(item: pystac.item.Item, product: DatasetType) -> Dataset:
     # pylint: disable=too-many-locals
     _cfg = getattr(product, "_stac_cfg", {})
     band2grid: Dict[str, str] = _cfg.get("band2grid", {})
+    ignore_proj: bool = _cfg.get("ignore_proj", False)
 
-    has_proj = has_proj_ext(item)
+    has_proj = False if ignore_proj else has_proj_ext(item)
     measurements: Dict[str, Dict[str, Any]] = {}
     grids: Dict[str, Dict[str, Any]] = {}
     crs = None
@@ -596,8 +625,13 @@ def item_to_ds(item: pystac.item.Item, product: DatasetType) -> Dataset:
                     "Expect all assets to share common CRS"
                 )  # pragma: no cover
 
-    # No proj metadata make up 1x1 Grid in EPSG4326 instead
+    # No proj metadata: make up 1x1 Grid in EPSG4326 instead
     if not has_proj:
+        # TODO: support partial proj, when only CRS is known but not shape/transform
+        # - get native CRS
+        # - compute bounding box in native CRS
+        # - construct 1x1 geobox in native CRS
+
         geom = Geometry(item.geometry, EPSG4326)
         geobox = _mk_1x1_geobox(geom)
         crs = geobox.crs
