@@ -10,11 +10,10 @@ import pystac.item
 import xarray
 from affine import Affine
 from datacube.model import Dataset
+from datacube.storage import measurement_paths
 from pyproj.crs.crs import CRS
 from toolz import dicttoolz
 
-from odc.index import patch_urls
-
 from ._dcload import dc_load
 from ._eo3 import ConversionConfig, stac2ds
 
@@ -121,6 +120,30 @@ def pick_best_resolution(
     return res_best
 
 
+def patch_urls(
+    ds: Dataset, edit: Callable[[str], str], bands: Optional[Iterable[str]] = None
+) -> Dataset:
+    """
+    Map function over dataset measurement urls.
+
+    :param ds: Dataset to edit in place
+    :param edit: Function that returns modified url from input url
+    :param bands: Only edit specified bands, default is to edit all
+    :return: Input dataset
+    """
+    resolved_paths = measurement_paths(ds)
+    if bands is None:
+        bands = list(resolved_paths)
+    else:
+        # remap aliases if present to their canonical name
+        bands = list(map(ds.type.canonical_measurement, bands))
+
+    mm = ds.metadata_doc["measurements"]
+    for band in bands:
+        mm[band]["path"] = edit(resolved_paths[band])
+    return ds
+
+
 # pylint: disable=too-many-arguments,too-many-locals
 def load(
     items: Iterable[pystac.item.Item],
@@ -140,7 +163,7 @@ def load(
     y: Optional[Tuple[float, float]] = None,
     align: Optional[Union[float, int, Tuple[float, float]]] = None,
     like: Optional[Any] = None,
-    geopolygon: Optional[datacube.utils.geometry.Geometry] = None,
+    geopolygon: Optional[Any] = None,
     # stac related
     stac_cfg: Optional[ConversionConfig] = None,
     patch_url: Optional[Callable[[str], str]] = None,
@@ -260,6 +283,13 @@ def load(
     :param like:
        Match output grid to the data loaded previously.
 
+    :param geopolygon:
+       Limit returned result to a bounding box of a given geometry. This could be an
+       instance of :class:`~datacube.utils.geometry.Geometry`, GeoJSON dictionary,
+       GeoPandas DataFrame, or any object implementing ``__geo_interface__``. We assume
+       ``EPSG:4326`` projection for dictionary and Shapely inputs. CRS information available
+       on GeoPandas inputs should be understood correctly.
+
     .. rubric:: STAC Related Options
 
     :param stac_cfg:
